"""Init File for weatherbit."""
from weatherbitpypi.client import Weatherbit
from weatherbitpypi.errors import WeatherbitError